==> react-uikit-badge-0.2.0.tgz: package/docs/badge-doc.jsx <==
'use strict';


import React from 'react';
import Codeblock from '../../react-uikit-codeblock/lib/codeblock';
import Table from '../../react-uikit-table/lib/table';
import Note from '../../react-uikit-note/lib/note';

const BadgeDoc = (props) => (
  <div>

    <section>
      <h1>Badge</h1>
        <p>
          Easlily create nicely looking badges to label and highlight your content.
        </p>
        <p>
          <a href='https://github.com/otissv/react-uikit-components'>react-uikit-components</a> for docs.
        </p>
      </section>

      <section>
        <h2>Usage</h2>
          <Codeblock>
  {`npm install react-uikit-badge --save;

  // ES6
  mport Badge from 'react-uikit-badge';

  // ES5
  var Badge = require;('react-uikit-badge');`}
        </Codeblock>
    </section>


    <section>
        <h2>Tests</h2>
        <p>
          <code>npm run test</code> to run tests with minimal output.<br />
          <code>npm run test:spec</code> to run tests with detailed output.<br />
          <code>npm run test:watch</code>watches all directories and run tests with minimal output on file changes.<br />
        </p>
      </section>

      <section>
        <h2>Build</h2>
        <p>
          <code>npm run build</code> to build files fro distribution.<br />
          <code>npm run build:watch</code> watches src directory and builds files on changes.<br />
        </p>
      </section>


      <section>
        <h2>Lint</h2>
        <p>
          <code>npm run lint</code> lints scripts in src directory.<br />
          <code>npm run lint:watch</code> watches src directory and lints scripts in src directory.<br />
        </p>
      </section>

      <section>
        <h2>License</h2>
          <p>MIT</p>
      </section>

  </div>
);

export default BadgeDoc;

==> react-uikit-badge-0.2.2.tgz: package/docs/badge-doc.jsx <==
'use strict';


import React from 'react';
import Codeblock from '../../react-uikit-codeblock/lib/codeblock';


const BadgeDoc = (props) => (
  <div>

    <section>
      <h1>React UIkit Badge</h1>
        <p>
          Easlily create nicely looking badges to label and highlight your content.
        </p>
        <p>
          <a href='http://otissv.github.io/react-uikit-components/'>http://otissv.github.io/react-uikit-components</a> for docs.
        </p>
      </section>

      <section>
        <h2>Usage</h2>
          <Codeblock>
  {`npm install react-uikit-badge --save;

  // ES6
  mport Badge from 'react-uikit-badge';

  // ES5
  var Badge = require;('react-uikit-badge');`}
        </Codeblock>
    </section>


    <section>
        <h2>Tests</h2>
        <p>
          <code>npm run test</code> to run tests with minimal output.<br />
          <code>npm run test:spec</code> to run tests with detailed output.<br />
          <code>npm run test:watch</code>watches all directories and run tests with minimal output on file changes.<br />
        </p>
      </section>

      <section>
        <h2>Build</h2>
        <p>
          <code>npm run build</code> to build files fro distribution.<br />
          <code>npm run build:watch</code> watches src directory and builds files on changes.<br />
        </p>
      </section>


      <section>
        <h2>Lint</h2>
        <p>
          <code>npm run lint</code> lints scripts in src directory.<br />
          <code>npm run lint:watch</code> watches src directory and lints scripts in src directory.<br />
        </p>
      </section>

      <section>
        <h2>License</h2>
          <p>MIT</p>
      </section>

  </div>
);

export default BadgeDoc;
